@@ -22,7 +22,7 @@
 #'
 #' @examples
 #' \dontrun{
-#' x <- seq(0, 2 * pi, pi / 100) ; y <-sin(x)
+#' x <- seq(0, 2 * pi, pi / 100) ; y <- sin(x)
 #' dy.dx(x, y, eval.point = 1.75)
 #'
 #' # Vector of derivatives
@@ -31,29 +31,31 @@
 
 dy.dx <- function(x, y, eval.point = median(x), deriv.method = "FD"){
 
+  if(any(class(x)=="tbl")) x <- as.vector(unlist(x))
+  if(any(class(y)=="tbl")) y <- as.vector(unlist(y))
+
   order <- NULL
 
-  dep <- NNS.dep(x, y)$Dependence
+  dep <- NNS.dep(x, y, asym =  TRUE)$Dependence
 
   if(dep > 0.85){
-      h <- 0.01
+    h <- 1/log(length(x),2)
   } else {
       if(dep > 0.5){
-          h <- 0.05
+        h <- 1/log(length(x))
       } else {
-          h <- 0.2
+        h <- 1/log(length(x),10)
       }
   }
 
 
+
   if(!is.null(ncol(x)) && is.null(colnames(x))){
     x <- data.frame(x)
     x <- unlist(x)
   }
 
-  if(length(eval.point) > 1 && deriv.method == "NNS"){
-    deriv.method <- "FD"
-  }
+  if(length(eval.point) > 1 && deriv.method == "NNS")  deriv.method <- "FD"
 
   if(is.character(eval.point)){
     ranges <- NNS.reg(x, y, order = order, plot = FALSE)$derivative
@@ -92,7 +94,7 @@ dy.dx <- function(x, y, eval.point = median(x), deriv.method = "FD"){
       run[z] <- eval.point.max[z] - eval.point.min[z]
     }
 
-    reg.output <- NNS.reg(x, y, plot = FALSE, return.values = TRUE, order = order, point.est = as.vector(deriv.points))
+    reg.output <- NNS.reg(x, y, plot = FALSE, point.est = as.vector(deriv.points), type = "XONLY", point.only = TRUE)
 
     estimates.min <- reg.output$Point.est[1:n]
     estimates.max <- reg.output$Point.est[(2*n+1):(3*n)]
