@@ -7,6 +7,7 @@ library(data.table)
 require(knitr)
 require(rgl)
 require(meboot)
+require(plyr)
 require(tdigest)
 require(dtw)
 
@@ -22,7 +23,7 @@ for(i in 1 : 4){NNS.part(x, y, order = i, type = "XONLY", Voronoi = TRUE)}
 NNS.part(x,y,order = 4, type = "XONLY")
 
 ## ----depreg},results='hide'---------------------------------------------------
-for(i in 1 : 3){NNS.part(x, y, order = i, min.obs.stop = FALSE, Voronoi = TRUE, type = "XONLY") ; NNS.reg(x, y, order = i, ncores = 1)}
+for(i in 1 : 3){NNS.part(x, y, order = i, obs.req = 0, Voronoi = TRUE) ; NNS.reg(x, y, order = i, ncores = 1)}
 
 ## ----nonlinear,fig.width=5,fig.height=3,fig.align = "center"------------------
 NNS.reg(x, y, ncores = 1)
@@ -49,13 +50,13 @@ a=NNS.reg(iris[ , 1 : 4], iris[ , 5], dim.red.method = "cor", threshold = .75, l
 NNS.reg(iris[ , 1 : 4], iris[ , 5], dim.red.method = "cor", threshold = .75, point.est = iris[1 : 10, 1 : 4], location = "topleft", ncores = 1)$Point.est
 
 ## ----class,fig.width=5,fig.height=3,fig.align = "center", message=FALSE-------
-NNS.reg(iris[ , 1 : 4], iris[ , 5], type = "CLASS", point.est = iris[1:10, 1 : 4], location = "topleft", ncores = 1)$Point.est
+NNS.reg(iris[ , 1 : 4], iris[ , 5], type = "CLASS", point.est = iris[1 : 10, 1 : 4], location = "topleft", ncores = 1)$Point.est
 
 ## ----stack,fig.width=5,fig.height=3,fig.align = "center", message=FALSE-------
 NNS.stack(IVs.train = iris[ , 1 : 4], 
           DV.train = iris[ , 5], 
-          IVs.test = iris[1:10, 1 : 4],
+          IVs.test = iris[1 : 10, 1 : 4],
           obj.fn = expression( mean(round(predicted) == actual) ),
-          objective = "max",
+          objective = "max", order = "max",
           type = "CLASS", folds = 1, ncores = 1)
 
